@@ -23,43 +23,52 @@ autocorr <- function(data, dvar, pvar, mvar, lag.max = 3, ...) {
   if (missing(pvar)) pvar <- scdf_attr(data, .opt$phase) else scdf_attr(data, .opt$phase) <- pvar
   if (missing(mvar)) mvar <- scdf_attr(data, .opt$mt) else scdf_attr(data, .opt$mt) <- mvar
 
-  data <- .SCprepareData(data)
+  data <- .prepare_scdf(data)
 
   N <- length(data)
-  case.names <- names(data)
-  if (is.null(case.names)) {
-    case.names <- paste("Case", 1:N, sep = "")
-  }
-  VAR <- paste0("lag_", 1:lag.max)
-
-  design <- rle(as.character(data[[1]][[pvar]]))$values
-
-  while (any(duplicated(design))) {
-    design[anyDuplicated(design)] <- paste0(design[anyDuplicated(design)], ".phase", anyDuplicated(design))
-  }
-
-
-  ac <- data.frame(case = rep(case.names, each = length(design) + 1), phase = rep(c(design, "all"), N))
-  ac[, VAR] <- NA
-
-
+  case_names <- .case_names(names(data), length(data))
+  var_lag <- paste0("Lag ", 1:lag.max)
+  
+  ac <- list()
   for (case in 1:N) {
     phases <- .phasestructure(data[[case]], pvar = pvar)
-
-    for (phase in 1:length(design)) {
+    
+    while (any(duplicated(phases$values))) {
+      phases$values[anyDuplicated(phases$values)] <- paste0(
+        phases$values[anyDuplicated(phases$values)], 
+        "_phase", 
+        anyDuplicated(phases$values)
+      )
+    }
+    
+    df <- data.frame(Phase = c(phases$values, "all"))
+    for (phase in 1:length(phases$values)) {
       y <- data[[case]][phases$start[phase]:phases$stop[phase], dvar]
       if (length(y) - 1 < lag.max) lag <- length(y) - 1 else lag <- lag.max
 
-      ac[(case - 1) * (length(design) + 1) + phase, VAR[1:lag]] <- acf(y, lag.max = lag, plot = FALSE, ...)$acf[-1]
+      .tmp <- acf(y, lag.max = lag, plot = FALSE, ...)$acf[-1]
+      df[phase, var_lag[1:lag]] <- .tmp
     }
+    
     y <- data[[case]][[dvar]]
     if (length(y) - 1 < lag.max) lag <- length(y) - 1 else lag <- lag.max
 
-    ac[(case - 1) * (length(design) + 1) + (length(design) + 1), VAR[1:lag]] <- acf(y, lag.max = lag, plot = FALSE, ...)$acf[-1]
+    .tmp <- acf(y, lag.max = lag, plot = FALSE, ...)$acf[-1]
+    df[length(phases$values) + 1, var_lag[1:lag]] <- .tmp
+    
+    ac[[case]] <- df
   }
-
-  out <- list(autocorr = ac, dvar = dvar)
-  class(out) <- c("sc", "autocorr")
+  
+  names(ac) <- case_names
+  
+  out <- list(
+    autocorr = ac, 
+    dvar = dvar
+  )
+  class(out) <- c("sc_ac")
+  attr(out, .opt$phase) <- pvar
+  attr(out, .opt$mt) <- mvar
+  attr(out, .opt$dv) <- dvar
   out
 }
 
