@@ -17,9 +17,12 @@
     scan.print.scdf.name = TRUE,
     scan.plot.style = "grid",
     scan.deprecated.warning = FALSE,
-    scan.export.kable = list(digits = 2),
+    scan.export.kable = list(digits = 2, linesep ="", booktab = TRUE),
     scan.export.kable_styling = list(
-      bootstrap_options = c("bordered", "condensed"), full_width = FALSE, position = "center"
+      bootstrap_options = c("bordered", "condensed"), 
+      full_width = FALSE, position = "left",
+      latex_options = c("hold_position"),
+      htmltable_class = "lightable-classic"
     )
   )
   
