@@ -15,22 +15,20 @@
 #' \code{\link{saveRDS}}
 #' @keywords manip
 #' @examples
-#' \dontrun{
 #' ## Write single-case data to a .csv-file
+#' filename <- tempfile()
 #' jessica <- rSC(design_rSC(level = .5))
-#' writeSC(jessica, "SCdata_Jessica.csv")
+#' writeSC(jessica, filename)
 #' 
 #' ## Write multiple cases to a .csv-file with semicolon as field and comma as decimal separator
-#' writeSC(Grosche2011, "MBDdata_Grosche.csv", sep = ";", dec = ",")
+#' writeSC(Grosche2011, filename, sep = ";", dec = ",")
 #' 
 #' ## writeSC and readSC
-#' filename <- file.path(tempdir(), "test.csv")
 #' writeSC(exampleA1B1A2B2_zvt, filename)
 #' dat <- readSC(filename, cvar = "case", pvar = "part", dvar = "zvt", mvar = "day")
-#' res1 <- describeSC(exampleA1B1A2B2_zvt)$descriptives
-#' res2 <- describeSC(dat)$descriptives
-#' identical(res1,res2)
-#' }
+#' res1 <- describe(exampleA1B1A2B2_zvt)$descriptives
+#' res2 <- describe(dat)$descriptives
+#' all.equal(res1,res2)
 #' @export
 writeSC <- function(data, filename = NULL, sep = ",", dec = ".", ...) {
   if(is.null(filename)) {
@@ -38,6 +36,13 @@ writeSC <- function(data, filename = NULL, sep = ",", dec = ".", ...) {
     cat("Write to file", filename, "\n\n")
   }
   
-  utils::write.table(longSCDF(data), file = filename, sep = sep, row.names = FALSE, dec = dec, ...)
+  utils::write.table(
+    as.data.frame(data), 
+    file = filename, 
+    sep = sep, 
+    dec = dec, 
+    row.names = FALSE, 
+    ...
+  )
   
 }
